@@ -123,7 +123,7 @@ class IMdata:
         else:
             print("No data loaded")
 
-    def make_map(self):
+    def make_map(self,fov=2500):
         # still in beta version, use with caution
         # ref : https://gist.github.com/hayesla/42596c72ab686171fe516f9ab43300e2
         hdu = fits.open(self.fname)
@@ -151,13 +151,13 @@ class IMdata:
                                            observatory='LOFAR')
         lofar_map = sunpy.map.Map(data, new_header)
         lofar_map_rotate = lofar_map.rotate()
-        bl = SkyCoord(-2500*u.arcsec, -2500*u.arcsec, frame=lofar_map_rotate.coordinate_frame)
-        tr = SkyCoord(2500*u.arcsec, 2500*u.arcsec, frame=lofar_map_rotate.coordinate_frame)
-        lofar_submap = lofar_map_rotate.submap(bl, tr)
+        bl = SkyCoord(-fov*u.arcsec, -fov*u.arcsec, frame=lofar_map_rotate.coordinate_frame)
+        tr = SkyCoord(fov*u.arcsec, fov*u.arcsec, frame=lofar_map_rotate.coordinate_frame)
+        lofar_submap = lofar_map_rotate.submap(bottom_left=bl, top_right=tr)
         return lofar_submap
 
 
-    def plot_image(self,vmax_set=np.nan,log_scale=False,fov=2500,FWHM=False):
+    def plot_image(self,vmax_set=np.nan,log_scale=False,fov=2500,FWHM=False,gaussian_sigma=0):
         if self.havedata:
             t_cur_datetime = self.t_obs
             solar_PA = sun_coord.P(self.t_obs).degree
@@ -165,7 +165,7 @@ class IMdata:
             [b_maj,b_min,b_angel] = self.get_beam()
             b_maj = b_maj*3600
             b_min = b_min*3600
-            data_new = gaussian_filter(self.data_xy_calib,sigma=9)
+            data_new = gaussian_filter(self.data_xy_calib,sigma=gaussian_sigma)
             xx = self.xx
             yy = self.yy
 
@@ -184,10 +184,10 @@ class IMdata:
                 vmax_now = 1.2*np.nanmax(data_new)
             ax.text(1400,1800, str(int(freq_cur)) + 'MHz',color='w')
             circle1 = plt.Circle((0,0), 960, color='r',fill=False)
-            beam0 = Ellipse((-500, -1800), b_maj, b_min, b_angel+solar_PA,color='w')
+            beam0 = Ellipse((-fov*0.3, -fov*0.9), b_maj, b_min, (b_angel-solar_PA),color='w')
             
             #print(b_maj,b_min,b_angel,solar_PA)
-            ax.text(-600,-1800,'Beam shape:',horizontalalignment='right',verticalalignment='center' ,color='w')
+            ax.text(-fov*0.35, -fov*0.9,'Beam shape:',horizontalalignment='right',verticalalignment='center' ,color='w')
             ax.add_artist(circle1)
             ax.add_artist(beam0)
             plt.xlabel('X (ArcSec)')
